==> v8.3.zip: ru_twords_ru_tw/bible/other/time.md <==
# время, времена

## Определение:

В Библии слово “время“ часто используется в переносном значении – для обозначения периода, в который происходят те или иные события. Это слово имеет значение, подобное значениям слов “век“ или “эпоха“.

* В книге пророка Даниила и в книге Откровение говорится о “времени“ великой скорби, которое наступит на Земле.
* В выражении “время, времена и полвремени“ слово “время“ означает “год“. Речь идёт о трёх с половиной годах великой скорби в конце нынешней эпохи.
* Словосочетание “прийти вовремя“ означает “прибыть в назначенное время без опоздания“.
* В зависимости от контекста слово “время“ можно перевести как “пора“, или “срок“, или “период времени“, или “событие“.
* Устойчивое словосочетание “времена и сроки“ — это образное выражение, в котором слова, обозначающие одно и то же, повторяются дважды для усиления. Это словосочетание можно также перевести как “события, происходящие в определённые периоды времени“. (См.: [дублет](rc://*/ta/man/translate/figs-doublet))
* Выражение “прежде вечных времён“ означает “давным-давно“ или “до сотворения мира“.

(См. также: [век](../other/age.md), [скорбь](../other/tribulation.md))

## Ссылки на библейский текст:

* [Деян. 1:7](rc://*/tn/help/act/01/07)
* [Дан. 12:1-2](rc://*/tn/help/dan/12/01)
* [Мк. 11:11](rc://*/tn/help/mrk/11/11)
* [Мф. 8:29](rc://*/tn/help/mat/08/29)
* [Пс. 68:28-29](rc://*/tn/help/psa/068/028)
* [Откр. 14:15](rc://*/tn/help/rev/14/15)

## Данные о слове:

* Номера Стронга: H116, H227, H268, H310, H570, H865, H1697, H1755, H2165, H2166, H2233, H2465, H3027, H3117, H3118, H3119, H3259, H3427, H3706, H3967, H4150, H4279, H4489, H4557, H5331, H5703, H5732, H5750, H5769, H6049, H6235, H6256, H6258, H6440, H6471, H6635, H6924, H7105, H7138, H7223, H7272, H7281, H7637, H7651, H7655, H7659, H7674, H7992, H8027, H8032, H8138, H8145, H8462, H8543, G744, G530, G1074, G1208, G1441, G1597, G1626, G1909, G2034, G2119, G2121, G2235, G2250, G2540, G3379, G3461, G3568, G3763, G3764, G3819, G3956, G3999, G4178, G4181, G4183, G4218, G4277, G4287, G4340, G4455, G5119, G5151, G5305, G5550, G5551, G5610

==> v9.2.zip: ru_twords_ru_tw/bible/other/time.md <==
# время, времена

## Определение:

В Библии слово “время“ часто используется в переносном значении – для обозначения периода, в который происходят те или иные события. Это слово имеет значение, подобное значениям слов “век“ или “эпоха“.

* В книге пророка Даниила и в книге Откровение говорится о “времени“ великой скорби, которое наступит на Земле.
* В выражении “время, времена и полвремени“ слово “время“ означает “год“. Речь идёт о трёх с половиной годах великой скорби в конце нынешней эпохи.
* Словосочетание “прийти вовремя“ означает “прибыть в назначенное время без опоздания“.
* В зависимости от контекста слово “время“ можно перевести как “пора“, или “срок“, или “период времени“, или “событие“.
* Устойчивое словосочетание “времена и сроки“ — это образное выражение, в котором слова, обозначающие одно и то же, повторяются дважды для усиления. Это словосочетание можно также перевести как “события, происходящие в определённые периоды времени“. (См.: [дублет](rc://ru/ta/man/translate/figs-doublet))
* Выражение “прежде вечных времён“ означает “давным-давно“ или “до сотворения мира“.

(См. также: [век](../other/age.md), [скорбь](../other/tribulation.md))

## Ссылки на библейский текст:

* [Деян. 1:7](rc://ru/tn/help/act/01/07)
* [Дан. 12:1-2](rc://ru/tn/help/dan/12/01)
* [Мк. 11:11](rc://ru/tn/help/mrk/11/11)
* [Мф. 8:29](rc://ru/tn/help/mat/08/29)
* [Пс. 68:28-29](rc://ru/tn/help/psa/068/028)
* [Откр. 14:15](rc://ru/tn/help/rev/14/15)

## Данные о слове:

* Номера Стронга: H116, H227, H268, H310, H570, H865, H1697, H1755, H2165, H2166, H2233, H2465, H3027, H3117, H3118, H3119, H3259, H3427, H3706, H3967, H4150, H4279, H4489, H4557, H5331, H5703, H5732, H5750, H5769, H6049, H6235, H6256, H6258, H6440, H6471, H6635, H6924, H7105, H7138, H7223, H7272, H7281, H7637, H7651, H7655, H7659, H7674, H7992, H8027, H8032, H8138, H8145, H8462, H8543, G744, G530, G1074, G1208, G1441, G1597, G1626, G1909, G2034, G2119, G2121, G2235, G2250, G2540, G3379, G3461, G3568, G3763, G3764, G3819, G3956, G3999, G4178, G4181, G4183, G4218, G4277, G4287, G4340, G4455, G5119, G5151, G5305, G5550, G5551, G5610
